pub mod graph;
pub mod math;
pub mod search;
pub mod sort;
pub mod subset;
pub mod tree;

#[cfg(test)]
mod tests {
    #[test]
    fn it_works() {
        assert_eq!(2 + 2, 4);
    }
}
